@@ -8,23 +8,20 @@
 
 BEGIN { $| = 1; print "1..2\n"; }
 END {print "not ok 1\n" unless $loaded;}
-use CGI::SSI qw( ssi get_content );
+use CGI::SSI;
 $loaded = 1;
 print "ok 1\n";
-eval {
-    $ENV{DOCUMENT_ROOT} = '.';
-    $ENV{QUERY_STRING} = 'query=value';
-    $CGI::SSI::allow_exec = 1;
-    my $html = ssi( get_content( 'test.shtml' ) );
-    warn $html;
-};
-
-warn $@ if $@;
-print "not " if $@;
-print "ok 2\n";
 
 ######################### End of black magic.
 
 # Insert your test code below (better if it prints "ok 13"
 # (correspondingly "not ok 13") depending on the success of chunk 13
 # of the test code):
+
+# set and echo
+
+my $ssi = CGI::SSI->new();
+$ssi->set(var => 'value');
+my $value = $ssi->echo('var');
+print 'not ' unless $value eq 'value';
+print "ok 2\n";
